# README #

A python package to Build Light Cones and output mock catalogues


Installation
------------

To install BLiC, you can either using pip::

    pip install blic

or using conda::

    conda install -c conda-forge blic

Installation
--------------


